// get a refrence to the canvas and its context
var canvas = document.getElementById("canvas"), canLeft = canvas.offsetLeft, canTop = canvas.offsetTop;
var scoreEl = $("#score"), comboEl = $("#combo");
var ctx = canvas.getContext("2d");

var images_src = ["404/fissure1.png", "404/fissure2.png", "404/fissure3.png", "404/fissure5.png", "404/fissure5.png", "404/olivier.png"];
var images = [];
// this array holds all spawned object
var objects = [];

// spawn a new object every 1500ms
var spawnRate;

// click combo
var combo = 1;

// user score
var score = 0;
var scoreIncrement = 404;
var halfLife = 30000;

var failCondition = 6;

// when was the last object spawned
var lastSpawn = -1;

var running = true;
var combo = 1;

var fps = 60;
var time;
var startTime;
var then;
var interval = 1000 / fps;
var delta;

$(document).ready(function() {
    // We load the images
    for(var i = 0; i < images_src.length; i++) {
        var img = new Image(); // width, height values are optional params 
        img.src = images_src[i];
		images.push(img);
    }
});

$("#startGame").click(function() {
    reset();

    resizeCanvas();

    $("#main").fadeOut();
    $("#canvas-container").fadeIn();
});

// resize the canvas to fill browser window dynamically
window.addEventListener('resize', resizeCanvas, false);

canvas.addEventListener('click', function(event) {
    var x = event.pageX - canLeft,
        y = event.pageY - canTop - 50;
	var ctx = canvas.getContext("2d");
	
    // Collision detection between clicked offset and element.
    objects.forEach(function(o) {
        if(y >= o.y && y < o.y + o.height && x >= o.x && x < o.x + o.width) {
            // o clicked
            handleClick(o);
            return;
        }
        combo = 1;
    });

}, false);

function resizeCanvas() {
    canvas.width = window.innerWidth;
    canvas.height = window.innerHeight - 70;

    /*
     * Your drawings need to be inside this function otherwise they will be reset when 
     * you resize the browser window and the canvas goes will be cleared.
     */
	if (running)
    	animate(); 
}

function reset() {
    objects = [];
    score = 0;
    spawnRate = 5000;
    combo = 1;
    then = Date.now();
    startTime = then;
}

function handleClick(o) {
    objects.remove(o);
    score += combo * scoreIncrement;
    spawnRate = 5000 * Math.exp(-(time - startTime) * 1 / halfLife);
    combo += 1;
}

function handleFail() {
    running = false;
    // canvas.fadeOut();
    alert("failed!");
}

function spawnRandomObject() {
    var img = images[Math.floor(Math.random() * images.length)];

    // create the new object
    var object = {
        // set position randomly
        x: Math.random() * (canvas.width - img.width),
        y: Math.random() * (canvas.height - img.height),
        // give random images
        image: img,
        height: img.height,
        width: img.width
    }

    // add the new object to the objects[] array
    objects.push(object);
}

function animate() {
    if(!running) {
        return;
    }

    scoreEl.html(score);
    comboEl.html(combo);

    // request another animation frame
    requestAnimationFrame(animate);

    // get the elapsed time
    time = Date.now();

    delta = time - then;
    
    if (delta > interval) {
        // see if its time to spawn a new object
        if (time > (lastSpawn + spawnRate)) {
            lastSpawn = time;
            spawnRandomObject();
        }
        // clear the canvas so all objects can be 
        // redrawn in new positions
        ctx.clearRect(0, 0, canvas.width, canvas.height);

        // move each object down the canvas
        for (var i = 0; i < objects.length; i++) {
            var object = objects[i];

            if(objects.length > failCondition) {
                handleFail();
                return;
            }

            ctx.drawImage(object.image, object.x, object.y, object.width, object.height);
        }

        then = time - (delta % interval);
    }

    then = time;
}

Array.prototype.remove = function() {
    var what, a = arguments, L = a.length, ax;
    while (L && this.length) {
        what = a[--L];
        while ((ax = this.indexOf(what)) !== -1) {
            this.splice(ax, 1);
        }
    }
    return this;
};
